Fleet Development Series
--------------------------

Aggregated from :ref:`Fleet Development Vessels`

.. note::
    available on platforms : Platform.Liquids, Platform.LNG, Platform.LPG, Platform.Dry

.. autoclass:: kpler.sdk.resources.fleet_development_series.FleetDevelopmentSeries
    :members:

.. autoclass:: kpler.sdk.FleetDevelopmentSeriesMetric
    :members:

.. autoclass:: kpler.sdk.FleetDevelopmentSeriesAggregationMetric
    :members:

.. autoclass:: kpler.sdk.FleetDevelopmentSeriesPeriod
    :members:

.. autoclass:: kpler.sdk.FleetDevelopmentSeriesSplit
    :members:

.. autoclass:: kpler.sdk.FleetDevelopmentSeriesUnit
    :members:

.. autoclass:: kpler.sdk.VesselTypesCPP
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesOil
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesLNG
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesLPG
    :members:
    :noindex:

.. autoclass:: kpler.sdk.VesselTypesDry
    :members:
    :noindex:
